
#ifndef KDEVPHPPARSER_EXPORT_H
#define KDEVPHPPARSER_EXPORT_H

#ifdef KDEVPHPPARSER_STATIC_DEFINE
#  define KDEVPHPPARSER_EXPORT
#  define KDEVPHPPARSER_NO_EXPORT
#else
#  ifndef KDEVPHPPARSER_EXPORT
#    ifdef kdevphpparser_EXPORTS
        /* We are building this library */
#      define KDEVPHPPARSER_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KDEVPHPPARSER_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KDEVPHPPARSER_NO_EXPORT
#    define KDEVPHPPARSER_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KDEVPHPPARSER_DEPRECATED
#  define KDEVPHPPARSER_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KDEVPHPPARSER_DEPRECATED_EXPORT
#  define KDEVPHPPARSER_DEPRECATED_EXPORT KDEVPHPPARSER_EXPORT KDEVPHPPARSER_DEPRECATED
#endif

#ifndef KDEVPHPPARSER_DEPRECATED_NO_EXPORT
#  define KDEVPHPPARSER_DEPRECATED_NO_EXPORT KDEVPHPPARSER_NO_EXPORT KDEVPHPPARSER_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KDEVPHPPARSER_NO_DEPRECATED
#    define KDEVPHPPARSER_NO_DEPRECATED
#  endif
#endif

#endif /* KDEVPHPPARSER_EXPORT_H */
