// THIS FILE IS GENERATED BY kdev-pg-qt 2.4.0
// WARNING! All changes made in this file will be lost!

#ifndef PHP_TOKEN_TYPE_H_INCLUDED
#define PHP_TOKEN_TYPE_H_INCLUDED

#include "parserexport.h"

# 45 "/build/kdevelop-php/src/kdev-php-26.08.0/parser/php.g" 1


#include <QtCore/QRegularExpression>

namespace KDevelop
{
class DUContext;
}


namespace Php
{

struct TokenTypeWrapper // to be imported by using inheritance
{
    enum TokenType
    {
        Token_ABSTRACT = 1001,
        Token_AND_ASSIGN = 1002,
        Token_ARRAY = 1003,
        Token_ARRAY_CAST = 1004,
        Token_AS = 1005,
        Token_ASSIGN = 1006,
        Token_AT = 1007,
        Token_BACKSLASH = 1008,
        Token_BACKTICK = 1009,
        Token_BANG = 1010,
        Token_BIT_AND = 1011,
        Token_BIT_OR = 1012,
        Token_BIT_XOR = 1013,
        Token_BOOLEAN_AND = 1014,
        Token_BOOLEAN_OR = 1015,
        Token_BOOL_CAST = 1016,
        Token_BREAK = 1017,
        Token_CALLABLE = 1018,
        Token_CASE = 1019,
        Token_CATCH = 1020,
        Token_CLASS = 1021,
        Token_CLASS_C = 1022,
        Token_CLONE = 1023,
        Token_CLOSE_TAG = 1024,
        Token_COLON = 1025,
        Token_COMMA = 1026,
        Token_COMMENT = 1027,
        Token_CONCAT = 1028,
        Token_CONCAT_ASSIGN = 1029,
        Token_CONST = 1030,
        Token_CONSTANT_ENCAPSED_STRING = 1031,
        Token_CONTINUE = 1032,
        Token_CURLY_OPEN = 1033,
        Token_DEC = 1034,
        Token_DECLARE = 1035,
        Token_DEFAULT = 1036,
        Token_DIR = 1037,
        Token_DIV = 1038,
        Token_DIV_ASSIGN = 1039,
        Token_DNUMBER = 1040,
        Token_DO = 1041,
        Token_DOC_COMMENT = 1042,
        Token_DOLLAR = 1043,
        Token_DOLLAR_OPEN_CURLY_BRACES = 1044,
        Token_DOUBLE_ARROW = 1045,
        Token_DOUBLE_CAST = 1046,
        Token_DOUBLE_QUOTE = 1047,
        Token_ECHO = 1048,
        Token_ELLIPSIS = 1049,
        Token_ELSE = 1050,
        Token_ELSEIF = 1051,
        Token_EMPTY = 1052,
        Token_ENCAPSED_AND_WHITESPACE = 1053,
        Token_ENDDECLARE = 1054,
        Token_ENDFOR = 1055,
        Token_ENDFOREACH = 1056,
        Token_ENDIF = 1057,
        Token_ENDSWITCH = 1058,
        Token_ENDWHILE = 1059,
        Token_END_HEREDOC = 1060,
        Token_END_NOWDOC = 1061,
        Token_EOF = 1000,
        Token_EVAL = 1062,
        Token_EXIT = 1063,
        Token_EXP = 1064,
        Token_EXP_ASSIGN = 1065,
        Token_EXTENDS = 1066,
        Token_FILE = 1067,
        Token_FINAL = 1068,
        Token_FINALLY = 1069,
        Token_FOR = 1070,
        Token_FOREACH = 1071,
        Token_FUNCTION = 1072,
        Token_FUNC_C = 1073,
        Token_GLOBAL = 1074,
        Token_GOTO = 1075,
        Token_HALT_COMPILER = 1076,
        Token_IF = 1077,
        Token_IMPLEMENTS = 1078,
        Token_INC = 1079,
        Token_INCLUDE = 1080,
        Token_INCLUDE_ONCE = 1081,
        Token_INLINE_HTML = 1082,
        Token_INSTANCEOF = 1083,
        Token_INSTEADOF = 1084,
        Token_INTERFACE = 1085,
        Token_INT_CAST = 1086,
        Token_INVALID = 1087,
        Token_ISSET = 1088,
        Token_IS_EQUAL = 1089,
        Token_IS_GREATER = 1090,
        Token_IS_GREATER_OR_EQUAL = 1091,
        Token_IS_IDENTICAL = 1092,
        Token_IS_NOT_EQUAL = 1093,
        Token_IS_NOT_IDENTICAL = 1094,
        Token_IS_SMALLER = 1095,
        Token_IS_SMALLER_OR_EQUAL = 1096,
        Token_LBRACE = 1097,
        Token_LBRACKET = 1098,
        Token_LINE = 1099,
        Token_LIST = 1100,
        Token_LNUMBER = 1101,
        Token_LOGICAL_AND = 1102,
        Token_LOGICAL_OR = 1103,
        Token_LOGICAL_XOR = 1104,
        Token_LPAREN = 1105,
        Token_METHOD_C = 1106,
        Token_MINUS = 1107,
        Token_MINUS_ASSIGN = 1108,
        Token_MOD = 1109,
        Token_MOD_ASSIGN = 1110,
        Token_MUL = 1111,
        Token_MUL_ASSIGN = 1112,
        Token_NAMESPACE = 1113,
        Token_NAMESPACE_C = 1114,
        Token_NEW = 1115,
        Token_NULL_COALESCE = 1116,
        Token_NUM_STRING = 1117,
        Token_OBJECT_CAST = 1118,
        Token_OBJECT_OPERATOR = 1119,
        Token_OPEN_TAG = 1120,
        Token_OPEN_TAG_WITH_ECHO = 1121,
        Token_OR_ASSIGN = 1122,
        Token_PAAMAYIM_NEKUDOTAYIM = 1123,
        Token_PLUS = 1124,
        Token_PLUS_ASSIGN = 1125,
        Token_PRINT = 1126,
        Token_PRIVATE = 1127,
        Token_PROTECTED = 1128,
        Token_PUBLIC = 1129,
        Token_QUESTION = 1130,
        Token_RBRACE = 1131,
        Token_RBRACKET = 1132,
        Token_REQUIRE = 1133,
        Token_REQUIRE_ONCE = 1134,
        Token_RETURN = 1135,
        Token_RPAREN = 1136,
        Token_SEMICOLON = 1137,
        Token_SL = 1138,
        Token_SL_ASSIGN = 1139,
        Token_SPACESHIP = 1140,
        Token_SR = 1141,
        Token_SR_ASSIGN = 1142,
        Token_START_HEREDOC = 1143,
        Token_START_NOWDOC = 1144,
        Token_STATIC = 1145,
        Token_STRING = 1146,
        Token_STRING_CAST = 1147,
        Token_STRING_VARNAME = 1148,
        Token_SWITCH = 1149,
        Token_THROW = 1150,
        Token_TILDE = 1151,
        Token_TRAIT = 1152,
        Token_TRAIT_C = 1153,
        Token_TRY = 1154,
        Token_UNSET = 1155,
        Token_UNSET_CAST = 1156,
        Token_USE = 1157,
        Token_VAR = 1158,
        Token_VARIABLE = 1159,
        Token_VOID = 1160,
        Token_WHILE = 1161,
        Token_WHITESPACE = 1162,
        Token_XOR_ASSIGN = 1163,
        Token_YIELD = 1164,
        Token_YIELD_FROM = 1165,
        TokenTypeSize
    }; // TokenType
}; // TokenTypeWrapper

typedef TokenTypeWrapper::TokenType TokenType;

} // end of namespace Php

#endif

