// THIS FILE IS GENERATED BY kdev-pg-qt 2.4.0
// WARNING! All changes made in this file will be lost!

#ifndef PHP_TOKEN_TEXT_H_INCLUDED
#define PHP_TOKEN_TEXT_H_INCLUDED

#include "parserexport.h"
#include "phptokentype.h"
namespace Php
{

QString tokenText(int token)
{
    switch (token)
    {
    case TokenTypeWrapper::Token_ABSTRACT:
        return QStringLiteral("abstract");
    case TokenTypeWrapper::Token_AND_ASSIGN:
        return QStringLiteral("&=");
    case TokenTypeWrapper::Token_ARRAY:
        return QStringLiteral("array");
    case TokenTypeWrapper::Token_ARRAY_CAST:
        return QStringLiteral("array cast");
    case TokenTypeWrapper::Token_AS:
        return QStringLiteral("as");
    case TokenTypeWrapper::Token_ASSIGN:
        return QStringLiteral("=");
    case TokenTypeWrapper::Token_AT:
        return QStringLiteral("@");
    case TokenTypeWrapper::Token_BACKSLASH:
        return QStringLiteral("\\\\");
    case TokenTypeWrapper::Token_BACKTICK:
        return QStringLiteral("`");
    case TokenTypeWrapper::Token_BANG:
        return QStringLiteral("!");
    case TokenTypeWrapper::Token_BIT_AND:
        return QStringLiteral("&");
    case TokenTypeWrapper::Token_BIT_OR:
        return QStringLiteral("|");
    case TokenTypeWrapper::Token_BIT_XOR:
        return QStringLiteral("^");
    case TokenTypeWrapper::Token_BOOLEAN_AND:
        return QStringLiteral("&&");
    case TokenTypeWrapper::Token_BOOLEAN_OR:
        return QStringLiteral("||");
    case TokenTypeWrapper::Token_BOOL_CAST:
        return QStringLiteral("bool cast");
    case TokenTypeWrapper::Token_BREAK:
        return QStringLiteral("break");
    case TokenTypeWrapper::Token_CALLABLE:
        return QStringLiteral("callable");
    case TokenTypeWrapper::Token_CASE:
        return QStringLiteral("case");
    case TokenTypeWrapper::Token_CATCH:
        return QStringLiteral("catch");
    case TokenTypeWrapper::Token_CLASS:
        return QStringLiteral("class");
    case TokenTypeWrapper::Token_CLASS_C:
        return QStringLiteral("__CLASS__");
    case TokenTypeWrapper::Token_CLONE:
        return QStringLiteral("clone");
    case TokenTypeWrapper::Token_CLOSE_TAG:
        return QStringLiteral("?>");
    case TokenTypeWrapper::Token_COLON:
        return QStringLiteral(":");
    case TokenTypeWrapper::Token_COMMA:
        return QStringLiteral(",");
    case TokenTypeWrapper::Token_COMMENT:
        return QStringLiteral("comment");
    case TokenTypeWrapper::Token_CONCAT:
        return QStringLiteral(".");
    case TokenTypeWrapper::Token_CONCAT_ASSIGN:
        return QStringLiteral(".=");
    case TokenTypeWrapper::Token_CONST:
        return QStringLiteral("const");
    case TokenTypeWrapper::Token_CONSTANT_ENCAPSED_STRING:
        return QStringLiteral("constant encapsed string");
    case TokenTypeWrapper::Token_CONTINUE:
        return QStringLiteral("continue");
    case TokenTypeWrapper::Token_CURLY_OPEN:
        return QStringLiteral("curly open");
    case TokenTypeWrapper::Token_DEC:
        return QStringLiteral("--");
    case TokenTypeWrapper::Token_DECLARE:
        return QStringLiteral("declare");
    case TokenTypeWrapper::Token_DEFAULT:
        return QStringLiteral("default");
    case TokenTypeWrapper::Token_DIR:
        return QStringLiteral("__DIR__");
    case TokenTypeWrapper::Token_DIV:
        return QStringLiteral("/");
    case TokenTypeWrapper::Token_DIV_ASSIGN:
        return QStringLiteral("/=");
    case TokenTypeWrapper::Token_DNUMBER:
        return QStringLiteral("double number");
    case TokenTypeWrapper::Token_DO:
        return QStringLiteral("do");
    case TokenTypeWrapper::Token_DOC_COMMENT:
        return QStringLiteral("doc comment");
    case TokenTypeWrapper::Token_DOLLAR:
        return QStringLiteral("$");
    case TokenTypeWrapper::Token_DOLLAR_OPEN_CURLY_BRACES:
        return QStringLiteral("${");
    case TokenTypeWrapper::Token_DOUBLE_ARROW:
        return QStringLiteral("=>");
    case TokenTypeWrapper::Token_DOUBLE_CAST:
        return QStringLiteral("double cast");
    case TokenTypeWrapper::Token_DOUBLE_QUOTE:
        return QStringLiteral("\\\"");
    case TokenTypeWrapper::Token_ECHO:
        return QStringLiteral("echo");
    case TokenTypeWrapper::Token_ELLIPSIS:
        return QStringLiteral("...");
    case TokenTypeWrapper::Token_ELSE:
        return QStringLiteral("else");
    case TokenTypeWrapper::Token_ELSEIF:
        return QStringLiteral("elseif");
    case TokenTypeWrapper::Token_EMPTY:
        return QStringLiteral("empty");
    case TokenTypeWrapper::Token_ENCAPSED_AND_WHITESPACE:
        return QStringLiteral("encapsed and whitespace");
    case TokenTypeWrapper::Token_ENDDECLARE:
        return QStringLiteral("enddeclare");
    case TokenTypeWrapper::Token_ENDFOR:
        return QStringLiteral("endfor");
    case TokenTypeWrapper::Token_ENDFOREACH:
        return QStringLiteral("endforeach");
    case TokenTypeWrapper::Token_ENDIF:
        return QStringLiteral("endif");
    case TokenTypeWrapper::Token_ENDSWITCH:
        return QStringLiteral("endswitch");
    case TokenTypeWrapper::Token_ENDWHILE:
        return QStringLiteral("endwhile");
    case TokenTypeWrapper::Token_END_HEREDOC:
        return QStringLiteral("end heredoc");
    case TokenTypeWrapper::Token_END_NOWDOC:
        return QStringLiteral("end nowdoc");
    case TokenTypeWrapper::Token_EOF:
        return QStringLiteral("end of file");
    case TokenTypeWrapper::Token_EVAL:
        return QStringLiteral("eval");
    case TokenTypeWrapper::Token_EXIT:
        return QStringLiteral("exit");
    case TokenTypeWrapper::Token_EXP:
        return QStringLiteral("**");
    case TokenTypeWrapper::Token_EXP_ASSIGN:
        return QStringLiteral("**=");
    case TokenTypeWrapper::Token_EXTENDS:
        return QStringLiteral("extends");
    case TokenTypeWrapper::Token_FILE:
        return QStringLiteral("__FILE__");
    case TokenTypeWrapper::Token_FINAL:
        return QStringLiteral("final");
    case TokenTypeWrapper::Token_FINALLY:
        return QStringLiteral("finally");
    case TokenTypeWrapper::Token_FOR:
        return QStringLiteral("for");
    case TokenTypeWrapper::Token_FOREACH:
        return QStringLiteral("foreach");
    case TokenTypeWrapper::Token_FUNCTION:
        return QStringLiteral("function");
    case TokenTypeWrapper::Token_FUNC_C:
        return QStringLiteral("__FUNCTION__");
    case TokenTypeWrapper::Token_GLOBAL:
        return QStringLiteral("global");
    case TokenTypeWrapper::Token_GOTO:
        return QStringLiteral("goto");
    case TokenTypeWrapper::Token_HALT_COMPILER:
        return QStringLiteral("halt compiler");
    case TokenTypeWrapper::Token_IF:
        return QStringLiteral("if");
    case TokenTypeWrapper::Token_IMPLEMENTS:
        return QStringLiteral("implements");
    case TokenTypeWrapper::Token_INC:
        return QStringLiteral("++");
    case TokenTypeWrapper::Token_INCLUDE:
        return QStringLiteral("include");
    case TokenTypeWrapper::Token_INCLUDE_ONCE:
        return QStringLiteral("include_once");
    case TokenTypeWrapper::Token_INLINE_HTML:
        return QStringLiteral("inline html");
    case TokenTypeWrapper::Token_INSTANCEOF:
        return QStringLiteral("instanceof");
    case TokenTypeWrapper::Token_INSTEADOF:
        return QStringLiteral("insteadof");
    case TokenTypeWrapper::Token_INTERFACE:
        return QStringLiteral("interface");
    case TokenTypeWrapper::Token_INT_CAST:
        return QStringLiteral("int cast");
    case TokenTypeWrapper::Token_INVALID:
        return QStringLiteral("invalid token");
    case TokenTypeWrapper::Token_ISSET:
        return QStringLiteral("isset");
    case TokenTypeWrapper::Token_IS_EQUAL:
        return QStringLiteral("==");
    case TokenTypeWrapper::Token_IS_GREATER:
        return QStringLiteral(">");
    case TokenTypeWrapper::Token_IS_GREATER_OR_EQUAL:
        return QStringLiteral(">=");
    case TokenTypeWrapper::Token_IS_IDENTICAL:
        return QStringLiteral("===");
    case TokenTypeWrapper::Token_IS_NOT_EQUAL:
        return QStringLiteral("!=");
    case TokenTypeWrapper::Token_IS_NOT_IDENTICAL:
        return QStringLiteral("!==");
    case TokenTypeWrapper::Token_IS_SMALLER:
        return QStringLiteral("<");
    case TokenTypeWrapper::Token_IS_SMALLER_OR_EQUAL:
        return QStringLiteral("<=");
    case TokenTypeWrapper::Token_LBRACE:
        return QStringLiteral("{");
    case TokenTypeWrapper::Token_LBRACKET:
        return QStringLiteral("[");
    case TokenTypeWrapper::Token_LINE:
        return QStringLiteral("__LINE__");
    case TokenTypeWrapper::Token_LIST:
        return QStringLiteral("list");
    case TokenTypeWrapper::Token_LNUMBER:
        return QStringLiteral("long number");
    case TokenTypeWrapper::Token_LOGICAL_AND:
        return QStringLiteral("logical and");
    case TokenTypeWrapper::Token_LOGICAL_OR:
        return QStringLiteral("logical or");
    case TokenTypeWrapper::Token_LOGICAL_XOR:
        return QStringLiteral("logical xor");
    case TokenTypeWrapper::Token_LPAREN:
        return QStringLiteral("(");
    case TokenTypeWrapper::Token_METHOD_C:
        return QStringLiteral("__METHOD__");
    case TokenTypeWrapper::Token_MINUS:
        return QStringLiteral("-");
    case TokenTypeWrapper::Token_MINUS_ASSIGN:
        return QStringLiteral("-=");
    case TokenTypeWrapper::Token_MOD:
        return QStringLiteral("%");
    case TokenTypeWrapper::Token_MOD_ASSIGN:
        return QStringLiteral("%=");
    case TokenTypeWrapper::Token_MUL:
        return QStringLiteral("*");
    case TokenTypeWrapper::Token_MUL_ASSIGN:
        return QStringLiteral("*=");
    case TokenTypeWrapper::Token_NAMESPACE:
        return QStringLiteral("namespace");
    case TokenTypeWrapper::Token_NAMESPACE_C:
        return QStringLiteral("__NAMESPACE__");
    case TokenTypeWrapper::Token_NEW:
        return QStringLiteral("new");
    case TokenTypeWrapper::Token_NULL_COALESCE:
        return QStringLiteral("??");
    case TokenTypeWrapper::Token_NUM_STRING:
        return QStringLiteral("num string");
    case TokenTypeWrapper::Token_OBJECT_CAST:
        return QStringLiteral("object cast");
    case TokenTypeWrapper::Token_OBJECT_OPERATOR:
        return QStringLiteral("->");
    case TokenTypeWrapper::Token_OPEN_TAG:
        return QStringLiteral("<?");
    case TokenTypeWrapper::Token_OPEN_TAG_WITH_ECHO:
        return QStringLiteral("<?=");
    case TokenTypeWrapper::Token_OR_ASSIGN:
        return QStringLiteral("|=");
    case TokenTypeWrapper::Token_PAAMAYIM_NEKUDOTAYIM:
        return QStringLiteral("::");
    case TokenTypeWrapper::Token_PLUS:
        return QStringLiteral("+");
    case TokenTypeWrapper::Token_PLUS_ASSIGN:
        return QStringLiteral("+=");
    case TokenTypeWrapper::Token_PRINT:
        return QStringLiteral("print");
    case TokenTypeWrapper::Token_PRIVATE:
        return QStringLiteral("private");
    case TokenTypeWrapper::Token_PROTECTED:
        return QStringLiteral("protected");
    case TokenTypeWrapper::Token_PUBLIC:
        return QStringLiteral("public");
    case TokenTypeWrapper::Token_QUESTION:
        return QStringLiteral("?");
    case TokenTypeWrapper::Token_RBRACE:
        return QStringLiteral("}");
    case TokenTypeWrapper::Token_RBRACKET:
        return QStringLiteral("]");
    case TokenTypeWrapper::Token_REQUIRE:
        return QStringLiteral("require");
    case TokenTypeWrapper::Token_REQUIRE_ONCE:
        return QStringLiteral("require_once");
    case TokenTypeWrapper::Token_RETURN:
        return QStringLiteral("return");
    case TokenTypeWrapper::Token_RPAREN:
        return QStringLiteral(")");
    case TokenTypeWrapper::Token_SEMICOLON:
        return QStringLiteral(";");
    case TokenTypeWrapper::Token_SL:
        return QStringLiteral("<<");
    case TokenTypeWrapper::Token_SL_ASSIGN:
        return QStringLiteral("<<=");
    case TokenTypeWrapper::Token_SPACESHIP:
        return QStringLiteral("<=>");
    case TokenTypeWrapper::Token_SR:
        return QStringLiteral(">>");
    case TokenTypeWrapper::Token_SR_ASSIGN:
        return QStringLiteral(">>=");
    case TokenTypeWrapper::Token_START_HEREDOC:
        return QStringLiteral("start heredoc");
    case TokenTypeWrapper::Token_START_NOWDOC:
        return QStringLiteral("start nowdoc");
    case TokenTypeWrapper::Token_STATIC:
        return QStringLiteral("static");
    case TokenTypeWrapper::Token_STRING:
        return QStringLiteral("string");
    case TokenTypeWrapper::Token_STRING_CAST:
        return QStringLiteral("string cast");
    case TokenTypeWrapper::Token_STRING_VARNAME:
        return QStringLiteral("string varname");
    case TokenTypeWrapper::Token_SWITCH:
        return QStringLiteral("switch");
    case TokenTypeWrapper::Token_THROW:
        return QStringLiteral("throw");
    case TokenTypeWrapper::Token_TILDE:
        return QStringLiteral("~");
    case TokenTypeWrapper::Token_TRAIT:
        return QStringLiteral("trait");
    case TokenTypeWrapper::Token_TRAIT_C:
        return QStringLiteral("__TRAIT__");
    case TokenTypeWrapper::Token_TRY:
        return QStringLiteral("try");
    case TokenTypeWrapper::Token_UNSET:
        return QStringLiteral("unset");
    case TokenTypeWrapper::Token_UNSET_CAST:
        return QStringLiteral("unset cast");
    case TokenTypeWrapper::Token_USE:
        return QStringLiteral("use");
    case TokenTypeWrapper::Token_VAR:
        return QStringLiteral("var ");
    case TokenTypeWrapper::Token_VARIABLE:
        return QStringLiteral("variable");
    case TokenTypeWrapper::Token_VOID:
        return QStringLiteral("void");
    case TokenTypeWrapper::Token_WHILE:
        return QStringLiteral("while");
    case TokenTypeWrapper::Token_WHITESPACE:
        return QStringLiteral("whitespace");
    case TokenTypeWrapper::Token_XOR_ASSIGN:
        return QStringLiteral("^=");
    case TokenTypeWrapper::Token_YIELD:
        return QStringLiteral("yield");
    case TokenTypeWrapper::Token_YIELD_FROM:
        return QStringLiteral("yield from");
    default:
        return QStringLiteral("unknown token");
    }
}
} // end of namespace Php

#endif

