// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDEVPHP_VERSION_H
#define KDEVPHP_VERSION_H

#define KDEVPHP_VERSION_STRING "6.0.260800"
#define KDEVPHP_VERSION_MAJOR 6
#define KDEVPHP_VERSION_MINOR 0
#define KDEVPHP_VERSION_PATCH 260800
#define KDEVPHP_VERSION ((6<<16)|(0<<8)|(260800))

#endif
